@@ -21,6 +21,10 @@
 #define TEST_TMP_DIR  "/tmp/swoole_core_test_dir"
 #define TEST_JPG_FILE "/examples/test.jpg"
 #define TEST_JPG_MD5SUM  "64a42b4c0f3c65a14c23b60d3880a917"
+#define TEST_HTTP_PROXY_PORT 8888
+#define TEST_HTTP_PROXY_HOST "127.0.0.1"
+
+#define ASSERT_MEMEQ(x,y,n)   ASSERT_EQ(memcmp((x), (y), n), 0)
 
 namespace swoole { namespace test {
 const std::string &get_root_path();
