@@ -3,15 +3,12 @@
 using namespace swoole;
 using namespace swoole::test;
 
-TEST(os_wait, waitpid_before_child_exit)
-{
-    test::coroutine::test([](void *arg)
-    {
+TEST(os_wait, waitpid_before_child_exit) {
+    test::coroutine::run([](void *arg) {
         pid_t pid = fork();
         ASSERT_NE(pid, -1);
 
-        if (pid == 0)
-        {
+        if (pid == 0) {
             usleep(100000);
             exit(0);
         }
@@ -23,15 +20,12 @@ TEST(os_wait, waitpid_before_child_exit)
     });
 }
 
-TEST(os_wait, waitpid_after_child_exit)
-{
-    test::coroutine::test([](void *arg)
-    {
+TEST(os_wait, waitpid_after_child_exit) {
+    test::coroutine::run([](void *arg) {
         pid_t pid = fork();
         ASSERT_NE(pid, -1);
 
-        if (pid == 0)
-        {
+        if (pid == 0) {
             exit(0);
         }
 
@@ -43,15 +37,12 @@ TEST(os_wait, waitpid_after_child_exit)
     });
 }
 
-TEST(os_wait, wait_before_child_exit)
-{
-    test::coroutine::test([](void *arg)
-    {
+TEST(os_wait, wait_before_child_exit) {
+    test::coroutine::run([](void *arg) {
         pid_t pid = fork();
         ASSERT_NE(pid, -1);
 
-        if (pid == 0)
-        {
+        if (pid == 0) {
             usleep(100000);
             exit(0);
         }
@@ -59,11 +50,9 @@ TEST(os_wait, wait_before_child_exit)
         int status = -1;
         pid_t pid2 = -1;
 
-        for (;;)
-        {
+        for (;;) {
             pid2 = swoole_coroutine_wait(&status);
-            if (pid2 == pid)
-            {
+            if (pid2 == pid) {
                 break;
             }
         }
@@ -72,15 +61,12 @@ TEST(os_wait, wait_before_child_exit)
     });
 }
 
-TEST(os_wait, wait_after_child_exit)
-{
-    test::coroutine::test([](void *arg)
-    {
+TEST(os_wait, wait_after_child_exit) {
+    test::coroutine::run([](void *arg) {
         pid_t pid = fork();
         ASSERT_NE(pid, -1);
 
-        if (pid == 0)
-        {
+        if (pid == 0) {
             exit(0);
         }
 
@@ -88,11 +74,9 @@ TEST(os_wait, wait_after_child_exit)
         int status = -1;
         pid_t pid2 = -1;
 
-        for (;;)
-        {
+        for (;;) {
             pid2 = swoole_coroutine_wait(&status);
-            if (pid2 == pid)
-            {
+            if (pid2 == pid) {
                 break;
             }
         }
