@@ -499,6 +499,12 @@ static sw_inline zend_bool ZVAL_IS_ARRAY(zval *v)
 }
 #endif
 
+#ifndef ZVAL_IS_OBJECT
+static sw_inline zend_bool ZVAL_IS_OBJECT(zval *v) {
+    return Z_TYPE_P(v) == IS_OBJECT;
+}
+#endif
+
 static sw_inline zval *sw_malloc_zval()
 {
     return (zval *) emalloc(sizeof(zval));
