@@ -40,7 +40,7 @@ static bool swoole_http2_server_respond(http_context *ctx, String *body);
 
 Http2Stream::Stream(Http2Session *client, uint32_t _id) {
     ctx = swoole_http_context_new(client->fd);
-    swoole_http_context_copy(client->default_ctx, ctx);
+    ctx->copy(client->default_ctx);
     ctx->http2 = true;
     ctx->stream = this;
     ctx->keepalive = true;
@@ -51,8 +51,8 @@ Http2Stream::Stream(Http2Session *client, uint32_t _id) {
 
 Http2Stream::~Stream() {
     ctx->stream = nullptr;
-    ctx->end = true;
-    swoole_http_context_free(ctx);
+    ctx->end_ = true;
+    ctx->free();
 }
 
 void Http2Stream::reset(uint32_t error_code) {
@@ -87,7 +87,7 @@ Http2Session::~Session() {
         nghttp2_hd_deflate_del(deflater);
     }
     if (default_ctx) {
-        efree(default_ctx);
+        delete default_ctx;
     }
     http2_sessions.erase(fd);
 }
@@ -172,7 +172,7 @@ static bool swoole_http2_is_static_file(Server *serv, http_context *ctx) {
         auto date_str_last_modified = handler.get_date_last_modified();
 
         zval *zheader = ctx->request.zserver;
-        swoole_http_response_set_header(ctx, ZEND_STRL("Last-Modified"), date_str.c_str(), date_str.length(), 0);
+        ctx->set_header(ZEND_STRL("Last-Modified"), date_str.c_str(), date_str.length(), 0);
 
         zval *zdate_if_modified_since = zend_hash_str_find(Z_ARR_P(zheader), ZEND_STRL("if-modified-since"));
         if (zdate_if_modified_since) {
@@ -244,7 +244,7 @@ static ssize_t http2_build_header(http_context *ctx, uchar *buffer, size_t body_
     char intbuf[2][16];
     int ret;
 
-    assert(ctx->send_header == 0);
+    assert(ctx->send_header_ == 0);
 
     // status code
     if (ctx->response.status == 0) {
@@ -314,7 +314,7 @@ static ssize_t http2_build_header(http_context *ctx, uchar *buffer, size_t body_
     // content encoding
 #ifdef SW_HAVE_COMPRESSION
     if (ctx->accept_compression) {
-        const char *content_encoding = swoole_http_get_content_encoding(ctx);
+        const char *content_encoding = ctx->get_content_encoding();
         headers.add(ZEND_STRL("content-encoding"), (char *) content_encoding, strlen(content_encoding));
     }
 #endif
@@ -353,7 +353,7 @@ static ssize_t http2_build_header(http_context *ctx, uchar *buffer, size_t body_
         return -1;
     }
 
-    ctx->send_header = 1;
+    ctx->send_header_ = 1;
     return rv;
 }
 
@@ -416,7 +416,7 @@ bool Http2Stream::send_header(size_t body_length, bool end_stream) {
     swoole_http_buffer->append(header_buffer, bytes);
 
     if (!ctx->send(ctx, swoole_http_buffer->str, swoole_http_buffer->length)) {
-        ctx->send_header = 0;
+        ctx->send_header_ = 0;
         return false;
     }
 
@@ -503,7 +503,7 @@ static bool swoole_http2_server_respond(http_context *ctx, String *body) {
     }
 
     // The headers has already been sent, retries are no longer allowed (even if send body failed)
-    ctx->end = 1;
+    ctx->end_ = 1;
 
     bool error = false;
 
@@ -602,7 +602,7 @@ static bool http2_context_sendfile(http_context *ctx, const char *file, uint32_t
     }
 
     const char *mimetype = swoole::mime_type::get(file).c_str();
-    swoole_http_response_set_header(ctx, ZEND_STRL("content-type"), mimetype, strlen(mimetype), 0);
+    ctx->set_header(ZEND_STRL("content-type"), mimetype, strlen(mimetype), 0);
 
     bool end_stream = (ztrailer == nullptr);
     if (!stream->send_header(length, end_stream)) {
@@ -610,7 +610,7 @@ static bool http2_context_sendfile(http_context *ctx, const char *file, uint32_t
     }
 
     /* headers has already been sent, retries are no longer allowed (even if send body failed) */
-    ctx->end = 1;
+    ctx->end_ = 1;
 
     bool error = false;
 
@@ -725,7 +725,7 @@ static int http2_parse_header(Http2Session *client, http_context *ctx, int flags
                             swWarn("invalid multipart/form-data body fd:%ld", ctx->fd);
                             return SW_ERR;
                         }
-                        swoole_http_parse_form_data(ctx, (char *) nv.value + nv.valuelen - boundary_len, boundary_len);
+                        ctx->parse_form_data((char *) nv.value + nv.valuelen - boundary_len, boundary_len);
                         ctx->parser.data = ctx;
                     }
                 } else if (SW_STRCASEEQ((char *) nv.name, nv.namelen, "cookie")) {
@@ -738,7 +738,7 @@ static int http2_parse_header(Http2Session *client, http_context *ctx, int flags
                 }
 #ifdef SW_HAVE_COMPRESSION
                 else if (ctx->enable_compression && SW_STRCASEEQ((char *) nv.name, nv.namelen, "accept-encoding")) {
-                    swoole_http_get_compression_method(ctx, (char *) nv.value, nv.valuelen);
+                    ctx->set_compression_method((char *) nv.value, nv.valuelen);
                 }
 #endif
                 add_assoc_stringl_ex(zheader, (char *) nv.name, nv.namelen, (char *) nv.value, nv.valuelen);
@@ -996,8 +996,8 @@ int swoole_http2_server_onFrame(Server *serv, Connection *conn, RecvData *req) {
 
     client->handle = swoole_http2_onRequest;
     if (!client->default_ctx) {
-        client->default_ctx = (http_context *) ecalloc(1, sizeof(http_context));
-        swoole_http_server_init_context(serv, client->default_ctx);
+        client->default_ctx = new http_context();
+        client->default_ctx->init(serv);
         client->default_ctx->fd = session_id;
         client->default_ctx->http2 = true;
         client->default_ctx->stream = (Http2Stream *) -1;
@@ -1022,8 +1022,8 @@ void swoole_http2_server_session_free(Connection *conn) {
     delete client;
 }
 
-void swoole_http2_response_end(http_context *ctx, zval *zdata, zval *return_value) {
-    swString http_body = {};
+void http_context::http2_end(zval *zdata, zval *return_value) {
+    String http_body = {};
     if (zdata) {
         http_body.length = php_swoole_get_send_data(zdata, &http_body.str);
     } else {
@@ -1031,7 +1031,7 @@ void swoole_http2_response_end(http_context *ctx, zval *zdata, zval *return_valu
         http_body.str = nullptr;
     }
 
-    RETURN_BOOL(swoole_http2_server_respond(ctx, &http_body));
+    RETURN_BOOL(swoole_http2_server_respond(this, &http_body));
 }
 
 #endif
