@@ -778,7 +778,7 @@ void HttpClient::apply_setting(zval *zset, const bool check_all) {
     if (socket) {
         php_swoole_client_set(socket, zset);
 #ifdef SW_USE_OPENSSL
-        if (socket->http_proxy && !socket->open_ssl)
+        if (socket->http_proxy && !socket->ssl_is_enable())
 #else
         if (socket->http_proxy)
 #endif
@@ -833,7 +833,9 @@ bool HttpClient::connect() {
             return false;
         }
 #ifdef SW_USE_OPENSSL
-        socket->open_ssl = ssl;
+        if (ssl) {
+            socket->enable_ssl_encrypt();
+        }
 #endif
         // apply settings
         apply_setting(
@@ -969,7 +971,7 @@ bool HttpClient::send() {
 
     // ============ path & proxy ============
 #ifdef SW_USE_OPENSSL
-    if (socket->http_proxy && !socket->open_ssl)
+    if (socket->http_proxy && !socket->ssl_is_enable())
 #else
     if (socket->http_proxy)
 #endif
