@@ -52,6 +52,9 @@ enum http_upload_errno {
 
 using http_request = swoole::http::Request;
 using http_context = swoole::http::Context;
+using swoole::Server;
+using swoole::Connection;
+using swoole::ListenPort;
 using swoole::microtime;
 
 static int http_request_on_path(swoole_http_parser *parser, const char *at, size_t length);
@@ -102,67 +105,8 @@ static inline char *http_trim_double_quote(char *ptr, int *len) {
     return tmp;
 }
 
-static sw_inline const char *http_get_method_name(int method) {
-    switch (method) {
-    case PHP_HTTP_GET:
-        return "GET";
-    case PHP_HTTP_POST:
-        return "POST";
-    case PHP_HTTP_HEAD:
-        return "HEAD";
-    case PHP_HTTP_PUT:
-        return "PUT";
-    case PHP_HTTP_DELETE:
-        return "DELETE";
-    case PHP_HTTP_PATCH:
-        return "PATCH";
-    case PHP_HTTP_CONNECT:
-        return "CONNECT";
-    case PHP_HTTP_OPTIONS:
-        return "OPTIONS";
-    case PHP_HTTP_TRACE:
-        return "TRACE";
-    case PHP_HTTP_COPY:
-        return "COPY";
-    case PHP_HTTP_LOCK:
-        return "LOCK";
-    case PHP_HTTP_MKCOL:
-        return "MKCOL";
-    case PHP_HTTP_MOVE:
-        return "MOVE";
-    case PHP_HTTP_PROPFIND:
-        return "PROPFIND";
-    case PHP_HTTP_PROPPATCH:
-        return "PROPPATCH";
-    case PHP_HTTP_UNLOCK:
-        return "UNLOCK";
-        /* subversion */
-    case PHP_HTTP_REPORT:
-        return "REPORT";
-    case PHP_HTTP_MKACTIVITY:
-        return "MKACTIVITY";
-    case PHP_HTTP_CHECKOUT:
-        return "CHECKOUT";
-    case PHP_HTTP_MERGE:
-        return "MERGE";
-        /* upnp */
-    case PHP_HTTP_MSEARCH:
-        return "MSEARCH";
-    case PHP_HTTP_NOTIFY:
-        return "NOTIFY";
-    case PHP_HTTP_SUBSCRIBE:
-        return "SUBSCRIBE";
-    case PHP_HTTP_UNSUBSCRIBE:
-        return "UNSUBSCRIBE";
-        /* proxy */
-    case PHP_HTTP_PURGE:
-        return "PURGE";
-        /* unknown */
-    case PHP_HTTP_NOT_IMPLEMENTED:
-        return "UNKNOWN";
-    default:
-        return nullptr;
-    }
+static sw_inline const char *http_get_method_name(enum swoole_http_method method) {
+    return swoole_http_method_str(method);
 }
 
 // clang-format off
@@ -192,8 +136,8 @@ static const multipart_parser_settings mt_parser_settings =
 };
 // clang-format on
 
-size_t swoole_http_requset_parse(http_context *ctx, const char *data, size_t length) {
-    return swoole_http_parser_execute(&ctx->parser, &http_parser_settings, data, length);
+size_t http_context::parse(const char *data, size_t length) {
+    return swoole_http_parser_execute(&parser, &http_parser_settings, data, length);
 }
 
 zend_class_entry *swoole_http_request_ce;
@@ -238,7 +182,7 @@ static void php_swoole_http_request_free_object(zend_object *object) {
     }
     if (ctx) {
         ctx->request.zobject = nullptr;
-        swoole_http_context_free(ctx);
+        ctx->free();
     }
 
     zend_object_std_dtor(&request->std);
@@ -257,6 +201,7 @@ static PHP_METHOD(swoole_http_request, getData);
 static PHP_METHOD(swoole_http_request, create);
 static PHP_METHOD(swoole_http_request, parse);
 static PHP_METHOD(swoole_http_request, isCompleted);
+static PHP_METHOD(swoole_http_request, getMethod);
 static PHP_METHOD(swoole_http_request, rawContent);
 static PHP_METHOD(swoole_http_request, __destruct);
 SW_EXTERN_C_END
@@ -281,6 +226,7 @@ const zend_function_entry swoole_http_request_methods[] =
     PHP_ME(swoole_http_request, create, arginfo_swoole_http_create, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
     PHP_ME(swoole_http_request, parse, arginfo_swoole_http_parse, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_http_request, isCompleted, arginfo_swoole_http_void, ZEND_ACC_PUBLIC)
+    PHP_ME(swoole_http_request, getMethod, arginfo_swoole_http_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_http_request, __destruct, arginfo_swoole_http_void, ZEND_ACC_PUBLIC)
     PHP_FE_END
 };
@@ -329,17 +275,15 @@ static int http_request_on_header_field(swoole_http_parser *parser, const char *
     return 0;
 }
 
-int swoole_http_parse_form_data(http_context *ctx, const char *boundary_str, int boundary_len) {
-    multipart_parser *mt_parser = multipart_parser_init(boundary_str, boundary_len, &mt_parser_settings);
+bool http_context::parse_form_data(const char *boundary_str, int boundary_len) {
+    mt_parser = multipart_parser_init(boundary_str, boundary_len, &mt_parser_settings);
     if (!mt_parser) {
         php_swoole_fatal_error(E_WARNING, "multipart_parser_init() failed");
-        return SW_ERR;
+        return false;
     }
 
-    ctx->mt_parser = mt_parser;
-    mt_parser->data = ctx;
-
-    return SW_OK;
+    mt_parser->data = this;
+    return true;
 }
 
 void swoole_http_parse_cookie(zval *zarray, const char *at, size_t length) {
@@ -445,14 +389,14 @@ static int http_request_on_header_value(swoole_http_parser *parser, const char *
         if (ctx->co_socket) {
             goto _add_header;
         }
-        swServer *serv = (swServer *) ctx->private_data;
-        swConnection *conn = serv->get_connection_by_session_id(ctx->fd);
+        Server *serv = (Server *) ctx->private_data;
+        Connection *conn = serv->get_connection_by_session_id(ctx->fd);
         if (!conn) {
             swoole_error_log(SW_LOG_NOTICE, SW_ERROR_SESSION_CLOSED, "session[%ld] is closed", ctx->fd);
             efree(header_name);
             return -1;
         }
-        swListenPort *port = serv->get_port_by_server_fd(conn->server_fd);
+        ListenPort *port = serv->get_port_by_server_fd(conn->server_fd);
         if (port->open_websocket_protocol) {
             conn->websocket_status = WEBSOCKET_STATUS_CONNECTION;
         }
@@ -491,12 +435,12 @@ static int http_request_on_header_value(swoole_http_parser *parser, const char *
                 boundary_len -= 2;
             }
             swTraceLog(SW_TRACE_HTTP, "form_data, boundary_str=%s", boundary_str);
-            swoole_http_parse_form_data(ctx, boundary_str, boundary_len);
+            ctx->parse_form_data(boundary_str, boundary_len);
         }
     }
 #ifdef SW_HAVE_COMPRESSION
     else if (ctx->enable_compression && SW_STREQ(header_name, header_len, "accept-encoding")) {
-        swoole_http_get_compression_method(ctx, at, length);
+        ctx->set_compression_method(at, length);
     }
 #endif
     else if (SW_STREQ(header_name, header_len, "transfer-encoding") && SW_STRCASECT(at, length, "chunked")) {
@@ -531,7 +475,7 @@ static int http_request_on_headers_complete(swoole_http_parser *parser) {
 
     ctx->keepalive = swoole_http_should_keep_alive(parser);
 
-    add_assoc_string(zserver, "request_method", (char *) http_get_method_name(parser->method));
+    add_assoc_string(zserver, "request_method", http_get_method_name(parser->method));
     add_assoc_stringl_ex(zserver, ZEND_STRL("request_uri"), ctx->request.path, ctx->request.path_len);
     // path_info should be decoded
     zend_string *zstr_path = zend_string_init(ctx->request.path, ctx->request.path_len, 0);
@@ -702,7 +646,7 @@ static int multipart_body_on_header_complete(multipart_parser *p) {
     }
 
     char file_path[SW_HTTP_UPLOAD_TMPDIR_SIZE];
-    sw_snprintf(file_path, SW_HTTP_UPLOAD_TMPDIR_SIZE, "%s/swoole.upfile.XXXXXX", ctx->upload_tmp_dir);
+    sw_snprintf(file_path, SW_HTTP_UPLOAD_TMPDIR_SIZE, "%s/swoole.upfile.XXXXXX", ctx->upload_tmp_dir.c_str());
     int tmpfile = swoole_tmpfile(file_path);
     if (tmpfile < 0) {
         return 0;
@@ -874,32 +818,32 @@ static int http_request_message_complete(swoole_http_parser *parser) {
 }
 
 #ifdef SW_HAVE_COMPRESSION
-void swoole_http_get_compression_method(http_context *ctx, const char *accept_encoding, size_t length) {
+void http_context::set_compression_method(const char *accept_encoding, size_t length) {
 #ifdef SW_HAVE_BROTLI
     if (swoole_strnpos(accept_encoding, length, ZEND_STRL("br")) >= 0) {
-        ctx->accept_compression = 1;
-        ctx->compression_method = HTTP_COMPRESS_BR;
+        accept_compression = 1;
+        compression_method = HTTP_COMPRESS_BR;
     } else
 #endif
         if (swoole_strnpos(accept_encoding, length, ZEND_STRL("gzip")) >= 0) {
-        ctx->accept_compression = 1;
-        ctx->compression_method = HTTP_COMPRESS_GZIP;
+        accept_compression = 1;
+        compression_method = HTTP_COMPRESS_GZIP;
     } else if (swoole_strnpos(accept_encoding, length, ZEND_STRL("deflate")) >= 0) {
-        ctx->accept_compression = 1;
-        ctx->compression_method = HTTP_COMPRESS_DEFLATE;
+        accept_compression = 1;
+        compression_method = HTTP_COMPRESS_DEFLATE;
     } else {
-        ctx->accept_compression = 0;
+        accept_compression = 0;
     }
 }
 
-const char *swoole_http_get_content_encoding(http_context *ctx) {
-    if (ctx->compression_method == HTTP_COMPRESS_GZIP) {
+const char *http_context::get_content_encoding() {
+    if (compression_method == HTTP_COMPRESS_GZIP) {
         return "gzip";
-    } else if (ctx->compression_method == HTTP_COMPRESS_DEFLATE) {
+    } else if (compression_method == HTTP_COMPRESS_DEFLATE) {
         return "deflate";
     }
 #ifdef SW_HAVE_BROTLI
-    else if (ctx->compression_method == HTTP_COMPRESS_BR) {
+    else if (compression_method == HTTP_COMPRESS_BR) {
         return "br";
     }
 #endif
@@ -959,7 +903,7 @@ static PHP_METHOD(swoole_http_request, create) {
     Z_PARAM_ARRAY(zoptions)
     ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
-    http_context *ctx = (http_context *) ecalloc(1, sizeof(http_context));
+    http_context *ctx = new http_context();
     object_init_ex(return_value, swoole_http_request_ce);
     zval *zrequest_object = &ctx->request._zobject;
     ctx->request.zobject = zrequest_object;
@@ -989,14 +933,22 @@ static PHP_METHOD(swoole_http_request, create) {
             } else if (SW_STRCASEEQ(key, keylen, "parse_files")) {
                 ctx->parse_files = zval_is_true(zvalue);
             }
-    #ifdef SW_HAVE_COMPRESSION
+#ifdef SW_HAVE_COMPRESSION
             else if (SW_STRCASEEQ(key, keylen, "enable_compression")) {
                 ctx->enable_compression = zval_is_true(zvalue);
             } else if (SW_STRCASEEQ(key, keylen, "compression_level")) {
                 ctx->compression_level = zval_get_long(zvalue);
             }
-    #endif
-            (void)keytype;
+#endif
+#ifdef SW_HAVE_ZLIB
+            else if (SW_STRCASEEQ(key, keylen, "websocket_compression")) {
+                ctx->websocket_compression = zval_is_true(zvalue);
+            }
+#endif
+            else if (SW_STRCASEEQ(key, keylen, "upload_tmp_dir")) {
+                ctx->upload_tmp_dir = zend::String(zvalue).to_std_string();
+            }
+            (void) keytype;
         }
         SW_HASHTABLE_FOREACH_END();
     }
@@ -1037,7 +989,16 @@ static PHP_METHOD(swoole_http_request, parse) {
         ZVAL_STR(&ctx->request.zdata, new_str);
     }
 
-    RETURN_LONG(swoole_http_requset_parse(ctx, str, l_str));
+    RETURN_LONG(ctx->parse(str, l_str));
+}
+
+static PHP_METHOD(swoole_http_request, getMethod) {
+    http_context *ctx = php_swoole_http_request_get_and_check_context(ZEND_THIS);
+    if (UNEXPECTED(!ctx)) {
+        RETURN_FALSE;
+    }
+    const char *method = http_get_method_name((ctx->parser).method);
+    RETURN_STRING(method);
 }
 
 static PHP_METHOD(swoole_http_request, isCompleted) {
