@@ -179,6 +179,10 @@ namespace network {
 struct Socket;
 struct Address;
 }  // namespace network
+class AsyncThreads;
+namespace async {
+class ThreadPool;
+}
 struct Protocol;
 struct EventData;
 struct DataHead;
@@ -390,6 +394,7 @@ enum swSocket_type {
     SW_SOCK_UDP6        = 4,
     SW_SOCK_UNIX_STREAM = 5,  // unix sock stream
     SW_SOCK_UNIX_DGRAM  = 6,  // unix sock dgram
+    SW_SOCK_RAW         = 7,
 };
 
 enum swEvent_type {
@@ -509,8 +514,6 @@ int swoole_get_systemd_listen_fds();
 void swoole_init(void);
 void swoole_clean(void);
 pid_t swoole_fork(int flags);
-double swoole_microtime(void);
-void swoole_rtrim(char *str, int len);
 void swoole_redirect_stdout(int new_fd);
 int swoole_shell_exec(const char *command, pid_t *pid, bool get_error_stream);
 int swoole_daemon(int nochdir, int noclose);
@@ -530,7 +533,7 @@ int swoole_set_cpu_affinity(cpu_set_t *set);
 #ifdef HAVE_CLOCK_GETTIME
 #define swoole_clock_gettime     clock_gettime
 #else
-int swoole_clock_gettime(clock_id_t which_clock, struct timespec *t);
+int swoole_clock_gettime(int which_clock, struct timespec *t);
 #endif
 
 static inline struct timespec swoole_time_until(int milliseconds) {
@@ -589,12 +592,7 @@ struct ThreadGlobal {
     String *buffer_stack;
     Reactor *reactor;
     Timer *timer;
-    uint8_t aio_init;
-    uint8_t aio_schedule;
-    uint32_t aio_task_num;
-    Pipe *aio_pipe;
-    network::Socket *aio_read_socket;
-    network::Socket *aio_write_socket;
+    AsyncThreads *async_threads;
     uint32_t signal_listener_num;
     uint32_t co_signal_listener_num;
     int error;
@@ -610,7 +608,6 @@ struct Allocator {
 struct Global {
     uchar init : 1;
     uchar running : 1;
-    uchar enable_coroutine : 1;
     uchar use_signalfd : 1;
     uchar wait_signal : 1;
     uchar enable_signalfd : 1;
@@ -657,6 +654,7 @@ struct Global {
 std::string dirname(const std::string &file);
 int hook_add(void **hooks, int type, const Callback &func, int push_back);
 void hook_call(void **hooks, int type, void *arg);
+double microtime(void);
 }
 
 extern swoole::Global SwooleG;                  // Local Global Variable
@@ -717,3 +715,6 @@ static sw_inline swoole::MemoryPool *sw_mem_pool() {
     return SwooleG.memory_pool;
 }
 
+static sw_inline const swoole::Allocator *sw_std_allocator() {
+    return &SwooleG.std_allocator;
+}
