@@ -93,6 +93,7 @@ class Socket {
     ssize_t recv_all(void *__buf, size_t __n);
     ssize_t send_all(const void *__buf, size_t __n);
     ssize_t recv_packet(double timeout = 0);
+    ssize_t recv_line(void *__buf, size_t maxlen);
     ssize_t recv_with_buffer(void *__buf, size_t __n);
 
     inline char *pop_packet() {
@@ -192,8 +193,6 @@ class Socket {
         return socket->info.get_port();
     }
 
-
-
     inline bool has_bound(const enum swEvent_type event = SW_EVENT_RDWR) {
         return get_bound_co(event) != nullptr;
     }
@@ -432,6 +431,14 @@ class Socket {
     inline bool init_sock();
     bool init_reactor_socket(int fd);
 
+    void check_return_value(ssize_t retval) {
+        if (retval >= 0) {
+            set_err(0);
+        } else if (errCode == 0) {
+            set_err(errno);
+        }
+    }
+
     inline void init_options() {
         if (type == SW_SOCK_TCP || type == SW_SOCK_TCP6) {
             set_option(IPPROTO_TCP, TCP_NODELAY, 1);
