@@ -123,17 +123,11 @@ void swoole_init(void) {
 
     SwooleG.running = 1;
     SwooleG.init = 1;
-    SwooleG.enable_coroutine = 1;
-
-    SwooleG.std_allocator.malloc = malloc;
-    SwooleG.std_allocator.calloc = calloc;
-    SwooleG.std_allocator.realloc = realloc;
-    SwooleG.std_allocator.free = free;
-
+    SwooleG.std_allocator = { malloc, calloc, realloc, free };
     SwooleG.fatal_error = swoole_fatal_error;
-
     SwooleG.cpu_num = SW_MAX(1, sysconf(_SC_NPROCESSORS_ONLN));
     SwooleG.pagesize = getpagesize();
+
     // get system uname
     uname(&SwooleG.uname);
     // random seed
@@ -214,6 +208,10 @@ SW_API int swoole_version_id(void) {
     return SWOOLE_VERSION_ID;
 }
 
+SW_API int swoole_api_version_id(void) {
+    return SWOOLE_API_VERSION_ID;
+}
+
 SW_EXTERN_C_END
 
 void swoole_clean(void) {
@@ -260,11 +258,8 @@ pid_t swoole_fork(int flags) {
         if (swoole_coroutine_is_in()) {
             swFatalError(SW_ERROR_OPERATION_NOT_SUPPORT, "must be forked outside the coroutine");
         }
-        if (SwooleTG.aio_init) {
-            printf("aio_init=%d, aio_task_num=%d, reactor=%p\n",
-                   SwooleTG.aio_init,
-                   SwooleTG.aio_task_num,
-                   SwooleTG.reactor);
+        if (SwooleTG.async_threads) {
+            swTrace("aio_task_num=%d, reactor=%p", SwooleTG.async_threads->task_num, SwooleTG.reactor);
             swFatalError(SW_ERROR_OPERATION_NOT_SUPPORT, "can not create server after using async file operation");
         }
     }
@@ -532,30 +527,6 @@ int swoole_version_compare(const char *version1, const char *version2) {
     return result;
 }
 
-double swoole_microtime(void) {
-    struct timeval t;
-    gettimeofday(&t, nullptr);
-    return (double) t.tv_sec + ((double) t.tv_usec / 1000000);
-}
-
-void swoole_rtrim(char *str, int len) {
-    int i;
-    for (i = len; i > 0;) {
-        switch (str[--i]) {
-        case ' ':
-        case '\0':
-        case '\n':
-        case '\r':
-        case '\t':
-        case '\v':
-            str[i] = 0;
-            break;
-        default:
-            return;
-        }
-    }
-}
-
 /**
  * Maximum common divisor
  */
@@ -874,5 +845,12 @@ std::string intersection(std::vector<std::string> &vec1, std::set<std::string> &
 
     return result;
 }
+
+double microtime(void) {
+    struct timeval t;
+    gettimeofday(&t, nullptr);
+    return (double) t.tv_sec + ((double) t.tv_usec / 1000000);
+}
+
 //-------------------------------------------------------------------------------
 };  // namespace swoole
