@@ -330,6 +330,96 @@ int swoole_coroutine_access(const char *pathname, int mode) {
     return retval;
 }
 
+FILE *swoole_coroutine_fopen(const char *pathname, const char *mode) {
+    if (sw_unlikely(is_no_coro())) {
+        return fopen(pathname, mode);
+    }
+
+    FILE *retval = nullptr;
+    swoole::coroutine::async([&]() { retval = fopen(pathname, mode); });
+    return retval;
+}
+
+FILE *swoole_coroutine_fdopen(int fd, const char *mode) {
+    if (sw_unlikely(is_no_coro())) {
+        return fdopen(fd, mode);
+    }
+
+    FILE *retval = nullptr;
+    swoole::coroutine::async([&]() { retval = fdopen(fd, mode); });
+    return retval;
+}
+
+FILE *swoole_coroutine_freopen(const char *pathname, const char *mode, FILE *stream) {
+    if (sw_unlikely(is_no_coro())) {
+        return freopen(pathname, mode, stream);
+    }
+
+    FILE *retval = nullptr;
+    swoole::coroutine::async([&]() { retval = freopen(pathname, mode, stream); });
+    return retval;
+}
+
+size_t swoole_coroutine_fread(void *ptr, size_t size, size_t nmemb, FILE *stream) {
+    if (sw_unlikely(is_no_coro())) {
+        return fread(ptr, size, nmemb, stream);
+    }
+
+    size_t retval = 0;
+    swoole::coroutine::async([&]() { retval = fread(ptr, size, nmemb, stream); });
+    return retval;
+}
+
+size_t swoole_coroutine_fwrite(const void *ptr, size_t size, size_t nmemb, FILE *stream) {
+    if (sw_unlikely(is_no_coro())) {
+        return fwrite(ptr, size, nmemb, stream);
+    }
+
+    size_t retval = 0;
+    swoole::coroutine::async([&]() { retval = fwrite(ptr, size, nmemb, stream); });
+    return retval;
+}
+
+char *swoole_coroutine_fgets(char *s, int size, FILE *stream) {
+    if (sw_unlikely(is_no_coro())) {
+        return fgets(s, size, stream);
+    }
+
+    char *retval = nullptr;
+    swoole::coroutine::async([&]() { retval = fgets(s, size, stream); });
+    return retval; 
+}
+
+int swoole_coroutine_fputs(const char *s, FILE *stream) {
+    if (sw_unlikely(is_no_coro())) {
+        return fputs(s, stream);
+    }
+
+    int retval = -1;
+    swoole::coroutine::async([&]() { retval = fputs(s, stream); });
+    return retval; 
+}
+
+int swoole_coroutine_feof(FILE *stream) {
+    if (sw_unlikely(is_no_coro())) {
+        return feof(stream);
+    }
+
+    int retval = -1;
+    swoole::coroutine::async([&]() { retval = feof(stream); });
+    return retval;
+}
+
+int swoole_coroutine_fclose(FILE *stream) {
+    if (sw_unlikely(is_no_coro())) {
+        return fclose(stream);
+    }
+
+    int retval = -1;
+    swoole::coroutine::async([&]() { retval = fclose(stream); });
+    return retval;
+}
+
 int swoole_coroutine_flock(int fd, int operation) {
     if (sw_unlikely(is_no_coro())) {
         return flock(fd, operation);
