@@ -758,7 +758,7 @@ bool Socket::check_liveness() {
 
 ssize_t Socket::peek(void *__buf, size_t __n) {
     ssize_t retval = socket->peek(__buf, __n, 0);
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
     return retval;
 }
 
@@ -783,7 +783,7 @@ ssize_t Socket::recv(void *__buf, size_t __n) {
     do {
         retval = socket->recv(__buf, __n, 0);
     } while (retval < 0 && socket->catch_error(errno) == SW_WAIT && timer.start() && wait_event(SW_EVENT_READ));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
     return retval;
 }
 
@@ -797,7 +797,7 @@ ssize_t Socket::send(const void *__buf, size_t __n) {
         retval = socket->send(__buf, __n, 0);
     } while (retval < 0 && socket->catch_error(errno) == SW_WAIT && timer.start() &&
              wait_event(SW_EVENT_WRITE, &__buf, __n));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
     return retval;
 }
 
@@ -810,10 +810,36 @@ ssize_t Socket::read(void *__buf, size_t __n) {
     do {
         retval = socket->read(__buf, __n);
     } while (retval < 0 && socket->catch_error(errno) == SW_WAIT && timer.start() && wait_event(SW_EVENT_READ));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
     return retval;
 }
 
+ssize_t Socket::recv_line(void *__buf, size_t maxlen) {
+    size_t n = 0;
+    ssize_t m = 0;
+    char *t = (char *) __buf;
+
+    *t = '\0';
+    while (*t != '\n' && *t != '\r' && n < maxlen) {
+        if (m > 0) {
+            t++;
+            n++;
+        }
+        if (n < maxlen) {
+            m = recv_with_buffer((void *) t, 1);
+            if (m < 0) {
+                return -1;
+            } else if (m == 0) {
+                return n > 0 ? n : 0;
+            }
+        }
+    }
+    if (n < maxlen) {
+        n++;
+    }
+    return n;
+}
+
 ssize_t Socket::recv_with_buffer(void *__buf, size_t __n) {
     if (sw_unlikely(!is_available(SW_EVENT_READ))) {
         return -1;
@@ -860,7 +886,7 @@ ssize_t Socket::write(const void *__buf, size_t __n) {
         retval = socket->write((void *) __buf, __n);
     } while (retval < 0 && socket->catch_error(errno) == SW_WAIT && timer.start() &&
              wait_event(SW_EVENT_WRITE, &__buf, __n));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
     return retval;
 }
 
@@ -873,7 +899,7 @@ ssize_t Socket::readv(network::IOVector *io_vector) {
     do {
         retval = socket->readv(io_vector);
     } while (retval < 0 && socket->catch_error(errno) == SW_WAIT && timer.start() && wait_event(SW_EVENT_READ));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
 
     return retval;
 }
@@ -919,7 +945,7 @@ ssize_t Socket::readv_all(network::IOVector *io_vector) {
 
     recv_barrier = &barrier;
     if (timer.start() && wait_event(SW_EVENT_READ)) {
-        set_err(retval < 0 ? errno : 0);
+        check_return_value(retval);
     }
     recv_barrier = nullptr;
 
@@ -935,7 +961,7 @@ ssize_t Socket::writev(network::IOVector *io_vector) {
     do {
         retval = socket->writev(io_vector);
     } while (retval < 0 && socket->catch_error(errno) == SW_WAIT && timer.start() && wait_event(SW_EVENT_WRITE));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
 
     return retval;
 }
@@ -981,7 +1007,7 @@ ssize_t Socket::writev_all(network::IOVector *io_vector) {
 
     send_barrier = &barrier;
     if (timer.start() && wait_event(SW_EVENT_WRITE)) {
-        set_err(retval < 0 ? errno : 0);
+        check_return_value(retval);
     }
     send_barrier = nullptr;
 
@@ -1016,7 +1042,7 @@ ssize_t Socket::recv_all(void *__buf, size_t __n) {
 
     recv_barrier = &barrier;
     if (timer.start() && wait_event(SW_EVENT_READ)) {
-        set_err(retval < 0 ? errno : 0);
+        check_return_value(retval);
     }
     recv_barrier = nullptr;
 
@@ -1051,7 +1077,7 @@ ssize_t Socket::send_all(const void *__buf, size_t __n) {
 
     send_barrier = &barrier;
     if (timer.start() && wait_event(SW_EVENT_WRITE)) {
-        set_err(retval < 0 ? errno : 0);
+        check_return_value(retval);
     }
     send_barrier = nullptr;
 
@@ -1067,7 +1093,7 @@ ssize_t Socket::recvmsg(struct msghdr *msg, int flags) {
     do {
         retval = ::recvmsg(sock_fd, msg, flags);
     } while (retval < 0 && socket->catch_error(errno) == SW_WAIT && timer.start() && wait_event(SW_EVENT_READ));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
     return retval;
 }
 
@@ -1083,7 +1109,7 @@ ssize_t Socket::sendmsg(const struct msghdr *msg, int flags) {
     do {
         retval = ::sendmsg(sock_fd, msg, flags);
     } while (retval < 0 && socket->catch_error(errno) == SW_WAIT && timer.start() && wait_event(SW_EVENT_WRITE));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
     return retval;
 }
 
@@ -1391,7 +1417,7 @@ ssize_t Socket::sendto(const std::string &host, int port, const void *__buf, siz
             swTraceLog(SW_TRACE_SOCKET, "sendto %ld/%ld bytes, errno=%d", retval, __n, errno);
         } while (retval < 0 && (errno == EINTR || (socket->catch_error(errno) == SW_WAIT && timer.start() &&
                                                    wait_event(SW_EVENT_WRITE, &__buf, __n))));
-        set_err(retval < 0 ? errno : 0);
+        check_return_value(retval);
     }
 
     return retval;
@@ -1416,7 +1442,7 @@ ssize_t Socket::recvfrom(void *__buf, size_t __n, struct sockaddr *_addr, sockle
         swTraceLog(SW_TRACE_SOCKET, "recvfrom %ld/%ld bytes, errno=%d", retval, __n, errno);
     } while (retval < 0 && ((errno == EINTR) ||
                             (socket->catch_error(errno) == SW_WAIT && timer.start() && wait_event(SW_EVENT_READ))));
-    set_err(retval < 0 ? errno : 0);
+    check_return_value(retval);
     return retval;
 }
 
