@@ -271,22 +271,26 @@ int Client::enable_ssl_encrypt() {
 }
 
 int Client::ssl_handshake() {
-    if (socket->ssl) {
+    if (socket->ssl_state == SW_SSL_STATE_READY) {
         return SW_ERR;
     }
-    ssl_context->http_v2 = http2;
-    if (!ssl_context->create()) {
-        return SW_ERR;
-    }
-    socket->ssl_send_ = 1;
-    if (socket->ssl_create(ssl_context.get(), SW_SSL_CLIENT) < 0) {
-        return SW_ERR;
+    if (!ssl_context->ready()) {
+        ssl_context->http_v2 = http2;
+        if (!ssl_context->create()) {
+            return SW_ERR;
+        }
     }
+    if (!socket->ssl) {
+        socket->ssl_send_ = 1;
+        if (socket->ssl_create(ssl_context.get(), SW_SSL_CLIENT) < 0) {
+            return SW_ERR;
+        }
 #ifdef SSL_CTRL_SET_TLSEXT_HOSTNAME
-    if (!ssl_context->tls_host_name.empty()) {
-        SSL_set_tlsext_host_name(socket->ssl, ssl_context->tls_host_name.c_str());
-    }
+        if (!ssl_context->tls_host_name.empty()) {
+            SSL_set_tlsext_host_name(socket->ssl, ssl_context->tls_host_name.c_str());
+        }
 #endif
+    }
     if (socket->ssl_connect() < 0) {
         return SW_ERR;
     }
@@ -454,7 +458,7 @@ int Client::close() {
             timer = nullptr;
         }
         // onClose callback
-        if (active && onClose) {
+        if (active) {
             active = 0;
             onClose(this);
         }
@@ -584,8 +588,8 @@ static int Client_tcp_connect_async(Client *cli, const char *host, int port, dou
         cli->buffer = new String(cli->input_buffer_size);
     }
 
-    if (!(cli->onConnect && cli->onError && cli->onClose)) {
-        swWarn("onConnect/onError/onClose callback have not set");
+    if (!(cli->onConnect && cli->onError && cli->onClose && cli->onReceive)) {
+        swWarn("onConnect/onError/onReceive/onClose callback have not set");
         return SW_ERR;
     }
 
@@ -718,12 +722,8 @@ static int Client_tcp_sendfile_async(Client *cli, const char *filename, off_t of
         swoole_set_last_error(errno);
         return SW_ERR;
     }
-    if (!(cli->socket->events & SW_EVENT_WRITE)) {
-        if (cli->socket->events & SW_EVENT_READ) {
-            return swoole_event_set(cli->socket, SW_EVENT_READ | SW_EVENT_WRITE);
-        } else {
-            return swoole_event_add(cli->socket, SW_EVENT_WRITE);
-        }
+    if (swoole_event_add_or_update(cli->socket, SW_EVENT_WRITE) == SW_ERR) {
+        return SW_ERR;
     }
     return SW_OK;
 }
@@ -776,6 +776,11 @@ static int Client_udp_connect(Client *cli, const char *host, int port, double ti
         return SW_ERR;
     }
 
+    if (cli->async && !cli->onReceive) {
+        swWarn("onReceive callback have not set");
+        return SW_ERR;
+    }
+
     cli->active = 1;
     cli->timeout = timeout;
     int bufsize = Socket::default_buffer_size;
@@ -954,11 +959,12 @@ static int Client_onStreamRead(Reactor *reactor, Event *event) {
             if (cli->ssl_handshake() < 0) {
                 goto _connect_fail;
             } else {
-                cli->socket->ssl_state = SW_SSL_STATE_WAIT_STREAM;
-                return swoole_event_set(event->socket, SW_EVENT_WRITE);
-            }
-            if (cli->onConnect) {
-                execute_onConnect(cli);
+                if (cli->socket->ssl_state == SW_SSL_STATE_READY) {
+                    execute_onConnect(cli);
+                }
+                else if (cli->socket->ssl_state == SW_SSL_STATE_WAIT_STREAM && cli->socket->ssl_want_write) {
+                    swoole_event_set(event->socket, SW_EVENT_WRITE);
+                }
             }
             return SW_OK;
         }
@@ -990,9 +996,7 @@ static int Client_onStreamRead(Reactor *reactor, Event *event) {
         } else
 #endif
         {
-            if (cli->onConnect) {
-                execute_onConnect(cli);
-            }
+            execute_onConnect(cli);
         }
         return SW_OK;
     }
@@ -1005,9 +1009,9 @@ static int Client_onStreamRead(Reactor *reactor, Event *event) {
         if (cli->socket->ssl_state != SW_SSL_STATE_READY) {
             return SW_OK;
         }
-        // ssl handshake sucess
-        else if (cli->onConnect) {
+        else {
             execute_onConnect(cli);
+            return SW_OK;
         }
     }
 #endif
@@ -1209,18 +1213,14 @@ static int Client_onWrite(Reactor *reactor, Event *event) {
         }
     _connect_success:
 #endif
-        if (cli->onConnect) {
-            execute_onConnect(cli);
-        }
+        execute_onConnect(cli);
     } else {
 #ifdef SW_USE_OPENSSL
     _connect_fail:
 #endif
         cli->active = 0;
         cli->close();
-        if (cli->onError) {
-            cli->onError(cli);
-        }
+        cli->onError(cli);
     }
 
     return SW_OK;
