@@ -122,6 +122,26 @@ int Socket::sendfile_blocking(const char *filename, off_t offset, size_t length,
     return SW_OK;
 }
 
+ssize_t Socket::writev_blocking(const struct iovec *iov, size_t iovcnt) {
+    while (1) {
+        ssize_t n = writev(iov, iovcnt);
+        if (n < 0) {
+            if (errno == EINTR) {
+                continue;
+            } else if (catch_error(errno) == SW_WAIT &&
+                       wait_event((int) (send_timeout_ * 1000), SW_EVENT_WRITE) == SW_OK) {
+                continue;
+            } else {
+                swSysWarn("send %lu bytes failed", iov[1].iov_len);
+                return SW_ERR;
+            }
+        } else {
+            return n;
+        }
+    }
+    return -1;
+}
+
 /**
  * clear socket buffer.
  */
@@ -532,7 +552,7 @@ int Socket::handle_sendfile() {
         ret = ::swoole_sendfile(fd, task->file.get_fd(), &task->offset, sendn);
     }
 
-    swTrace("ret=%d|task->offset=%ld|sendn=%d|filesize=%ld", ret, (long) task->offset, sendn, task->length);
+    swTrace("ret=%d|task->offset=%ld|sendn=%lu|filesize=%lu", ret, (long) task->offset, sendn, task->length);
 
     if (ret <= 0) {
         switch (catch_error(errno)) {
@@ -726,6 +746,14 @@ ssize_t Socket::send(const void *__buf, size_t __n, int __flags) {
     return retval;
 }
 
+ssize_t Socket::send_async(const void *__buf, size_t __n) {
+    if (!swoole_event_is_available()) {
+        return send_blocking(__buf, __n);
+    } else {
+        return swoole_event_write(this, __buf, __n);
+    }
+}
+
 ssize_t Socket::readv(IOVector *io_vector) {
     ssize_t retval;
 
@@ -743,6 +771,7 @@ ssize_t Socket::readv(IOVector *io_vector) {
 
     return retval;
 }
+
 ssize_t Socket::writev(IOVector *io_vector) {
     ssize_t retval;
 
@@ -944,6 +973,56 @@ X509 *Socket::ssl_get_peer_certificate() {
     return SSL_get_peer_certificate(ssl);
 }
 
+STACK_OF(X509) *Socket::ssl_get_peer_cert_chain() {
+    if (!ssl) {
+        return NULL;
+    }
+    return SSL_get_peer_cert_chain(ssl);
+}
+
+static int _ssl_read_x509_file(X509 *cert, char *buffer, size_t length) {
+    long len;
+    BIO *bio = BIO_new(BIO_s_mem());
+    ON_SCOPE_EXIT {
+        BIO_free(bio);
+    };
+
+    if (bio == nullptr) {
+        swWarn("BIO_new() failed");
+        return -1;
+    }
+
+    if (PEM_write_bio_X509(bio, cert) == 0) {
+        swWarn("PEM_write_bio_X509() failed");
+        return -1;
+    }
+
+    len = BIO_pending(bio);
+    if (len < 0 && len > (long) length) {
+        swWarn("certificate length[%ld] is too big", len);
+        return -1;
+    }
+    return BIO_read(bio, buffer, len);
+}
+
+std::vector<std::string> Socket::ssl_get_peer_cert_chain(int limit) {
+    std::vector<std::string> list;
+    STACK_OF(X509) *chain = ssl_get_peer_cert_chain();
+    if (chain == nullptr) {
+        return list;
+    }
+    auto n = sk_X509_num(chain);
+    n = std::min(n, limit);
+    SW_LOOP_N(n) {
+        X509 *cert = sk_X509_value(chain, i);
+        auto n = _ssl_read_x509_file(cert, sw_tg_buffer()->str, sw_tg_buffer()->size);
+        if (n > 0) {
+            list.emplace_back(sw_tg_buffer()->str, n);
+        }
+    }
+    return list;
+}
+
 bool Socket::ssl_get_peer_certificate(String *buf) {
     int n = ssl_get_peer_certificate(buf->str, buf->size);
     if (n < 0) {
@@ -955,47 +1034,16 @@ bool Socket::ssl_get_peer_certificate(String *buf) {
 }
 
 int Socket::ssl_get_peer_certificate(char *buffer, size_t length) {
-    long len;
-    BIO *bio;
-    X509 *cert;
-    int n;
-
-    cert = ssl_get_peer_certificate();
+    X509 *cert = ssl_get_peer_certificate();
     if (cert == nullptr) {
         return SW_ERR;
     }
-
-    bio = BIO_new(BIO_s_mem());
-    if (bio == nullptr) {
-        swWarn("BIO_new() failed");
-        X509_free(cert);
-        return SW_ERR;
-    }
-
-    if (PEM_write_bio_X509(bio, cert) == 0) {
-        swWarn("PEM_write_bio_X509() failed");
-        goto _failed;
-    }
-
-    len = BIO_pending(bio);
-    if (len < 0 && len > (long) length) {
-        swWarn("certificate length[%ld] is too big", len);
-        goto _failed;
-    }
-
-    n = BIO_read(bio, buffer, len);
-
-    BIO_free(bio);
-    X509_free(cert);
-
-    return n;
-
-_failed:
-
-    BIO_free(bio);
-    X509_free(cert);
-
-    return SW_ERR;
+    ON_SCOPE_EXIT {
+        if (cert) {
+            X509_free(cert);
+        }
+    };
+    return _ssl_read_x509_file(cert, buffer, length);
 }
 
 enum swReturn_code Socket::ssl_accept() {
@@ -1110,7 +1158,7 @@ int Socket::ssl_sendfile(const File &fp, off_t *_offset, size_t _size) {
         } else {
             *_offset += ret;
         }
-        swTraceLog(SW_TRACE_REACTOR, "fd=%d, readn=%d, n=%d, ret=%d", fd, readn, n, ret);
+        swTraceLog(SW_TRACE_REACTOR, "fd=%d, readn=%ld, n=%ld, ret=%ld", fd, readn, n, ret);
         return ret;
     } else {
         swSysWarn("pread() failed");
@@ -1340,10 +1388,10 @@ ssize_t Socket::ssl_writev(IOVector *io_vector) {
     return total_bytes > 0 ? total_bytes : retval;
 }
 
-int Socket::ssl_create(SSL_CTX *_ssl_context, int _flags) {
+int Socket::ssl_create(SSLContext *ssl_context, int _flags) {
     ssl_clear_error();
 
-    ssl = SSL_new(_ssl_context);
+    ssl = SSL_new(ssl_context->get_context());
     if (ssl == nullptr) {
         swWarn("SSL_new() failed");
         return SW_ERR;
