@@ -122,7 +122,7 @@ int ReactorEpoll::add(Socket *socket, int events) {
 
     reactor_->_add(socket, events);
     swTraceLog(
-        SW_TRACE_EVENT, "add events[fd=%d#%d, type=%d, events=%d]", socket->fd, reactor_->id, socket->fd_type, events_);
+        SW_TRACE_EVENT, "add events[fd=%d#%d, type=%d, events=%d]", socket->fd, reactor_->id, socket->fd_type, events);
 
     return SW_OK;
 }
@@ -165,7 +165,7 @@ int ReactorEpoll::set(Socket *socket, int events) {
         return SW_ERR;
     }
 
-    swTraceLog(SW_TRACE_EVENT, "set event[reactor_id=%d, fd=%d, events=%d]", reactor_->id, socket->fd, events_);
+    swTraceLog(SW_TRACE_EVENT, "set event[reactor_id=%d, fd=%d, events=%d]", reactor_->id, socket->fd, events);
     reactor_->_set(socket, events);
 
     return SW_OK;
