@@ -15,6 +15,8 @@
 */
 
 #include "swoole_server.h"
+#include "swoole_util.h"
+
 #include <unordered_map>
 #include <vector>
 
@@ -198,17 +200,17 @@ int Server::start_manager_process() {
     return SW_OK;
 }
 
-void Server::check_worker_exit_status(int worker_id, pid_t pid, int status) {
-    if (status != 0) {
+void Server::check_worker_exit_status(int worker_id, const ExitStatus &exit_status) {
+    if (exit_status.get_status() != 0) {
         swWarn("worker#%d[pid=%d] abnormal exit, status=%d, signal=%d"
                "%s",
                worker_id,
-               pid,
-               WEXITSTATUS(status),
-               WTERMSIG(status),
-               WTERMSIG(status) == SIGSEGV ? "\n" SWOOLE_BUG_REPORT : "");
+               exit_status.get_pid(),
+               exit_status.get_code(),
+               exit_status.get_signal(),
+               exit_status.get_signal() == SIGSEGV ? "\n" SWOOLE_BUG_REPORT : "");
         if (onWorkerError != nullptr) {
-            onWorkerError(this, worker_id, pid, status);
+            onWorkerError(this, worker_id, exit_status);
         }
     }
 }
@@ -220,11 +222,11 @@ int Manager::start(Server *_server) {
     SwooleG.use_signalfd = 0;
     SwooleTG.reactor = nullptr;
 
-    reload_workers = (Worker *) sw_calloc(_server->worker_num + _server->task_worker_num, sizeof(Worker));
-    if (reload_workers == nullptr) {
-        swError("malloc[reload_workers] failed");
-        return SW_ERR;
-    }
+    reload_workers = new Worker[_server->worker_num + _server->task_worker_num];
+    ON_SCOPE_EXIT {
+        delete[] reload_workers;
+        reload_workers = nullptr;
+    };
 
     // for reload
     swSignal_set(SIGHUP, nullptr);
@@ -255,8 +257,7 @@ int Manager::start(Server *_server) {
     }
 
     while (_server->running) {
-        int status;
-        pid_t pid = wait(&status);
+        ExitStatus exit_status = wait_process();
 
         if (read_message) {
             WorkerStopMessage msg;
@@ -282,7 +283,7 @@ int Manager::start(Server *_server) {
             swoole_timer_select();
         }
 
-        if (pid < 0) {
+        if (exit_status.get_pid() < 0) {
             if (!reloading) {
             _error:
                 if (errno > 0 && errno != EINTR) {
@@ -355,12 +356,12 @@ int Manager::start(Server *_server) {
             // event workers
             SW_LOOP_N(_server->worker_num) {
                 // find worker
-                if (pid != _server->workers[i].pid) {
+                if (exit_status.get_pid() != _server->workers[i].pid) {
                     continue;
                 }
 
                 // check the process return code and signal
-                _server->check_worker_exit_status(i, pid, status);
+                _server->check_worker_exit_status(i, exit_status);
 
                 while (1) {
                     Worker *worker = _server->get_worker(i);
@@ -377,17 +378,17 @@ int Manager::start(Server *_server) {
 
             // task worker
             if (_server->gs->task_workers.map_) {
-                auto iter = _server->gs->task_workers.map_->find(pid);
+                auto iter = _server->gs->task_workers.map_->find(exit_status.get_pid());
                 if (iter != _server->gs->task_workers.map_->end()) {
-                    _server->check_worker_exit_status(iter->second->id, pid, status);
+                    _server->check_worker_exit_status(iter->second->id, exit_status);
                     _server->spawn_task_worker(iter->second);
                 }
             }
             // user process
             if (_server->user_worker_map != nullptr) {
-                Server::wait_other_worker(&_server->gs->event_workers, pid, status);
+                Server::wait_other_worker(&_server->gs->event_workers, exit_status);
             }
-            if (pid == reload_worker_pid && reloading) {
+            if (exit_status.get_pid() == reload_worker_pid && reloading) {
                 reload_worker_i++;
             }
         }
@@ -414,8 +415,6 @@ int Manager::start(Server *_server) {
         }
     }
 
-    sw_free(reload_workers);
-
     if (SwooleTG.timer) {
         swoole_timer_free();
     }
@@ -510,14 +509,14 @@ void Manager::signal_handler(int sig) {
 /**
  * @return: success returns pid, failure returns SW_ERR.
  */
-int Server::wait_other_worker(ProcessPool *pool, pid_t pid, int status) {
+int Server::wait_other_worker(ProcessPool *pool, const ExitStatus &exit_status) {
     Server *serv = (Server *) pool->ptr;
     Worker *exit_worker = nullptr;
     int worker_type;
 
     do {
         if (serv->gs->task_workers.map_) {
-            auto iter = serv->gs->task_workers.map_->find(pid);
+            auto iter = serv->gs->task_workers.map_->find(exit_status.get_pid());
             if (iter != serv->gs->task_workers.map_->end()) {
                 worker_type = SW_PROCESS_TASKWORKER;
                 exit_worker = iter->second;
@@ -525,7 +524,7 @@ int Server::wait_other_worker(ProcessPool *pool, pid_t pid, int status) {
             }
         }
         if (serv->user_worker_map) {
-            auto iter = serv->user_worker_map->find(pid);
+            auto iter = serv->user_worker_map->find(exit_status.get_pid());
             if (iter != serv->user_worker_map->end()) {
                 worker_type = SW_PROCESS_USERWORKER;
                 exit_worker = iter->second;
@@ -535,7 +534,7 @@ int Server::wait_other_worker(ProcessPool *pool, pid_t pid, int status) {
         return SW_ERR;
     } while (0);
 
-    serv->check_worker_exit_status(exit_worker->id, pid, status);
+    serv->check_worker_exit_status(exit_worker->id, exit_status);
 
     pid_t new_process_pid = -1;
 
