@@ -597,8 +597,8 @@ int Server::start_event_worker(Worker *worker) {
  */
 ssize_t Server::send_to_reactor_thread(const EventData *ev_data, size_t sendn, SessionId session_id) {
     Socket *pipe_sock = get_reactor_thread_pipe(session_id, ev_data->info.reactor_id);
-    if (SwooleTG.reactor) {
-        return SwooleTG.reactor->write(SwooleTG.reactor, pipe_sock, ev_data, sendn);
+    if (swoole_event_is_available()) {
+        return swoole_event_write(pipe_sock, ev_data, sendn);
     } else {
         return pipe_sock->send_blocking(ev_data, sendn);
     }
@@ -606,7 +606,7 @@ ssize_t Server::send_to_reactor_thread(const EventData *ev_data, size_t sendn, S
 
 ssize_t Server::send_to_reactor_thread(const DataHead *head, const iovec *iov, size_t iovcnt, SessionId session_id) {
     Socket *pipe_sock = get_reactor_thread_pipe(session_id, head->reactor_id);
-    if (SwooleTG.reactor) {
+    if (swoole_event_is_available()) {
         return swoole_event_writev(pipe_sock, iov, iovcnt);
     } else {
         return pipe_sock->writev_blocking(iov, iovcnt);
